@@ -1,4 +1,5 @@
 """Console script for environment_backups."""
+import logging
 import sys
 from platform import python_version
 from typing import List
@@ -10,10 +11,10 @@ from environment_backups import CONFIGURATION_MANAGER, CONSOLE
 from environment_backups import __version__ as current_version
 from environment_backups.backups.cli_commands import backup
 from environment_backups.config.cli_commands import config
-import logging
 
 logger = logging.getLogger(__name__)
 
+
 @click.group()
 def main():
     """Main entrypoint."""
@@ -21,14 +22,14 @@ def main():
 
 @click.command()
 def about():
+    # Add available configurations
     app_name = CONFIGURATION_MANAGER.APP_NAME.replace('-', ' ').title()
-    content: List[str] = []
-    content.append(f'Operating System: {sys.platform}')
-    content.append(f'Python : {python_version()}')
-    content.append(f'Configuration file: {CONFIGURATION_MANAGER.config_file}')
+    content: List[str] = [f'Operating System: {sys.platform}', f'Python : {python_version()}',
+                          f'Configuration file: {CONFIGURATION_MANAGER.config_file}']
     panel = Panel('\n'.join(content), title=app_name, subtitle=f"version: {current_version}")
     CONSOLE.print(panel)
 
+# TODO add configurations and status
 
 
 main.add_command(backup)
