@@ -8,12 +8,7 @@ LOG_FILE = CONFIGURATION_MANAGER.logs_folder / f'{CONFIGURATION_MANAGER.APP_NAME
 LOGGING = {
     "version": 1,
     "disable_existing_loggers": False,
-    "formatters": {
-        "verbose": {
-            "format": "%(levelname)s %(asctime)s %(module)s "
-                      "%(process)d %(thread)d %(message)s"
-        }
-    },
+    "formatters": {"verbose": {"format": "%(levelname)s %(asctime)s %(module)s " "%(process)d %(thread)d %(message)s"}},
     "handlers": {
         "console": {
             "level": "DEBUG",
@@ -26,15 +21,16 @@ LOGGING = {
             "formatter": "verbose",
             "filename": str(LOG_FILE),
             "maxBytes": 1024,
-            "backupCount": 3
-        }
-    },
-    "loggers": {
-        'environment_backups': {
-            "level": "DEBUG",
-            "handlers": ['console', 'file'],
-            "propagate": False
+            "backupCount": 3,
         },
     },
-    "root": {"level": "INFO", "handlers": ["console", ]},
+    "loggers": {
+        'environment_backups': {"level": "DEBUG", "handlers": ['console', 'file'], "propagate": False},
+    },
+    "root": {
+        "level": "INFO",
+        "handlers": [
+            "console",
+        ],
+    },
 }
