@@ -1,20 +1,22 @@
+import json
 from pathlib import Path
 
 import pytest
 from freezegun import freeze_time
 
-from environment_backups.backups.backups import (list_all_projects, get_projects_envs, backup_envs, backup_environment)
+from environment_backups.backups.backups import backup_envs, backup_environment
+from environment_backups.backups.projects import list_all_projects, get_projects_envs
 from environment_backups.compression import zip_folder_with_pwd
 from environment_backups.exceptions import ConfigurationError
 from tests.factories import projects_folder_tree_factory
 
 
-# TODO Fix broken tests
-
 def test_list_all_projects_with_existing_folders(mocker):
     # Mock os.scandir to return a list of mock directories
-    mocker.patch('os.scandir', return_value=[mocker.Mock(is_dir=lambda: True, path='dir1'),
-                                             mocker.Mock(is_dir=lambda: True, path='dir2')])
+    mocker.patch(
+        'os.scandir',
+        return_value=[mocker.Mock(is_dir=lambda: True, path='dir1'), mocker.Mock(is_dir=lambda: True, path='dir2')],
+    )
     assert list_all_projects(Path('/some/path')) == ['dir1', 'dir2']
 
 
@@ -26,18 +28,18 @@ def test_list_all_projects_with_no_folders(mocker):
 
 def test_get_projects_envs_with_valid_data(mocker):
     # Mock list_all_projects to return specific folders
-    mocker.patch('environment_backups.backups.backups.list_all_projects', return_value=['project1', 'project2'])
+    mocker.patch('environment_backups.backups.projects.list_all_projects', return_value=['project1', 'project2'])
     # Mock Path.exists to return True
     mocker.patch('pathlib.Path.exists', return_value=True)
     expected_result = {
         'project1': {'envs': Path('project1/env_folder')},
-        'project2': {'envs': Path('project2/env_folder')}
+        'project2': {'envs': Path('project2/env_folder')},
     }
     assert get_projects_envs(Path('/projects'), ['env_folder']) == expected_result
 
 
 def test_get_projects_envs_with_no_projects(mocker):
-    mocker.patch('environment_backups.backups.backups.list_all_projects', return_value=[])
+    mocker.patch('environment_backups.backups.projects.list_all_projects', return_value=[])
     assert get_projects_envs(Path('/projects'), ['env_folder']) == {}
 
 
@@ -82,7 +84,8 @@ def test_zip_folder_with_empty_directory(mocker, tmp_path):
 
 
 @freeze_time("2023-11-02 13:16:12")
-def test_backup_envs_with_valid_data(tmp_path):
+@pytest.mark.asyncio
+async def test_backup_envs_with_valid_data(tmp_path):
     # Mock get_projects_envs to return a dictionary of projects with environments
     projects_folder, _ = projects_folder_tree_factory(root_folder=tmp_path)
 
@@ -93,11 +96,8 @@ def test_backup_envs_with_valid_data(tmp_path):
     backup_folder.mkdir()
 
     # Call the function
-    zip_list, b_folder = backup_envs(
-        projects_folder=projects_folder,
-        backup_folder=backup_folder,
-        environment_folders=['.envs'],
-        password=None
+    zip_list, b_folder = await backup_envs(
+        projects_folder=projects_folder, backup_folder=backup_folder, environment_folders=['.envs'], password=None
     )
 
     # Assertions
@@ -107,23 +107,32 @@ def test_backup_envs_with_valid_data(tmp_path):
     assert zip_list[0].exists()
 
 
-def test_backup_environments_with_valid_configuration(tmp_path, mocker):
+@pytest.mark.asyncio
+async def test_backup_environments_with_valid_configuration(tmp_path, fixtures_folder, mocker):
+    mock_config_file = fixtures_folder / 'app_configuration.json'
+    with open(mock_config_file, 'r') as f:
+        config = json.load(f)
+
     projects_folder, _ = projects_folder_tree_factory(root_folder=tmp_path, projects_folder_name='PycharmProjects')
     backup_folder = tmp_path / 'backups'
     backup_folder.mkdir()
     mock_date = '2012-01-14 13:01:45'
     mock_configuration = {
         "name": "test_env",
-        "project_folder": f"{projects_folder}",
+        "projects_folder": f"{projects_folder}",
         "backup_folder": f"{backup_folder}",
         "computer_name": "adl-computer",
     }
-    mocker.patch('environment_backups.backups.backups.get_configuration_by_name',
-                 return_value=(mock_configuration, 100.0))
-    # Mock CONFIGURATION_MANAGER and get_configuration_by_name
+    config['configurations'].append(mock_configuration)
 
+    mocker.patch(
+        'environment_backups.backups.backups.get_configuration_by_name', return_value=(mock_configuration, 100.0)
+    )
+    # Mock CONFIGURATION_MANAGER and get_configuration_by_name
+    mocker.patch("environment_backups.backups.backups.CONFIGURATION_MANAGER.get_current",
+                 return_value=config)
     with freeze_time(mock_date):
-        zip_list, b_folder = backup_environment('test_env')
+        zip_list, b_folder = await backup_environment('test_env', use_async=False)
 
     # Assertions
     assert len(zip_list) == 1
@@ -132,14 +141,12 @@ def test_backup_environments_with_valid_configuration(tmp_path, mocker):
     assert b_folder == backup_folder / '20120114_13'
 
 
-def test_backup_environments_with_invalid_configuration(mocker):
+@pytest.mark.asyncio
+async def test_backup_environments_with_invalid_configuration(mocker):
     # Mock CONFIGURATION_MANAGER and get_configuration_by_name to return None
-    mocker.patch(
-        'environment_backups.backups.backups.get_configuration_by_name',
-        return_value=(None, 100.0)
-    )
+    mocker.patch('environment_backups.backups.backups.get_configuration_by_name', return_value=(None, 100.0))
 
     # Test with an invalid configuration to raise ConfigurationError
     with pytest.raises(ConfigurationError) as excinfo:
-        backup_environment('invalid_env')
+        await backup_environment('invalid_env', use_async=False)
     assert 'No environment configuration found for "invalid_env"' in str(excinfo.value)
